@@ -1,14 +1,14 @@
 from pydantic import BaseModel, Field, model_validator
-from typing import Generic, Literal, Optional, TypeVar
+from typing import Annotated, Generic, Literal, Optional, TypeVar
 from urllib.parse import quote_plus, urlencode
-from maleo.types.base.boolean import OptionalBoolean
-from maleo.types.base.dict import (
+from maleo.types.boolean import OptionalBoolean
+from maleo.types.dict import (
     OptionalStringToAnyDict,
     StringToAnyDict,
     StringToStringDict,
 )
-from maleo.types.base.integer import OptionalInteger
-from maleo.types.base.string import OptionalString
+from maleo.types.integer import OptionalInteger
+from maleo.types.string import OptionalString
 from ..enums import (
     Connection,
     Driver,
@@ -40,13 +40,16 @@ class BaseConnectionConfig(
     database: DatabaseT = Field(..., description="Database's name")
 
     # Optional fields for different database types
-    auth_source: OptionalString = Field(
-        None, description="Authentication database (Mongo)"
-    )
-    ssl: OptionalBoolean = Field(None, description="Enable SSL connection")
-    options: OptionalStringToAnyDict = Field(
-        default_factory=dict, description="Additional connection options"
-    )
+    auth_source: Annotated[
+        OptionalString, Field(None, description="Authentication database (Mongo)")
+    ] = None
+    ssl: Annotated[
+        OptionalBoolean, Field(None, description="Enable SSL connection")
+    ] = None
+    options: Annotated[
+        OptionalStringToAnyDict,
+        Field(default_factory=dict, description="Additional connection options"),
+    ] = None
 
     @model_validator(mode="after")
     def validate_required_fields_per_driver(self):
@@ -245,12 +248,16 @@ class MySQLConnectionConfig(
     BaseConnectionConfig[Literal[Driver.MYSQL], str, str, str, int, str]
 ):
     driver: Literal[Driver.MYSQL] = Driver.MYSQL
-    port: int = Field(3306, description="MySQL port")
-    username: str = Field("root", description="MySQL username")
+    port: Annotated[int, Field(3306, description="MySQL port")] = 3306
+    username: Annotated[str, Field("root", description="MySQL username")] = "root"
 
     # MySQL-specific options
-    echo: bool = Field(False, description="Enable SQL statement logging")
-    charset: MySQLCharset = Field(MySQLCharset.UTF8MB4, description="Character set")
+    echo: Annotated[bool, Field(False, description="Enable SQL statement logging")] = (
+        False
+    )
+    charset: Annotated[
+        MySQLCharset, Field(MySQLCharset.UTF8MB4, description="Character set")
+    ] = MySQLCharset.UTF8MB4
 
     def _make_mysql_url(self, connection: Connection = Connection.ASYNC) -> str:
         """MySQL database URL format with proper async/sync drivers."""
@@ -280,15 +287,22 @@ class PostgreSQLConnectionConfig(
     BaseConnectionConfig[Literal[Driver.POSTGRESQL], str, str, str, int, str]
 ):
     driver: Literal[Driver.POSTGRESQL] = Driver.POSTGRESQL
-    port: int = Field(5432, description="PostgreSQL port")
-    username: str = Field("postgres", description="PostgreSQL username")
+    port: Annotated[int, Field(5432, description="PostgreSQL port")] = 5432
+    username: Annotated[str, Field("postgres", description="PostgreSQL username")] = (
+        "postgres"
+    )
 
     # PostgreSQL-specific options
-    echo: bool = Field(False, description="Enable SQL statement logging")
-    sslmode: Optional[PostgreSQLSSLMode] = Field(None, description="SSL mode")
-    application_name: OptionalString = Field(
-        None, description="Application name for connection tracking"
+    echo: Annotated[bool, Field(False, description="Enable SQL statement logging")] = (
+        False
     )
+    sslmode: Annotated[
+        Optional[PostgreSQLSSLMode], Field(None, description="SSL mode")
+    ] = None
+    application_name: Annotated[
+        OptionalString,
+        Field(None, description="Application name for connection tracking"),
+    ] = None
 
     def _make_postgresql_url(self, connection: Connection = Connection.ASYNC) -> str:
         """PostgreSQL database URL format with proper async/sync drivers."""
@@ -322,15 +336,19 @@ class SQLiteConnectionConfig(
     BaseConnectionConfig[Literal[Driver.SQLITE], None, None, None, None, str]
 ):
     driver: Literal[Driver.SQLITE] = Driver.SQLITE
-    database: str = Field(..., min_length=1, description="SQLite database file path")
+    database: Annotated[
+        str, Field(..., description="SQLite database file path", min_length=1)
+    ]
 
     # SQLite doesn't need these fields
-    username: None = Field(None, description="Not used in SQLite")
-    password: None = Field(None, description="Not used in SQLite")
-    host: None = Field(None, description="Not used in SQLite")
-    port: None = Field(None, description="Not used in SQLite")
+    username: Annotated[None, Field(None, description="Not used in SQLite")] = None
+    password: Annotated[None, Field(None, description="Not used in SQLite")] = None
+    host: Annotated[None, Field(None, description="Not used in SQLite")] = None
+    port: Annotated[None, Field(None, description="Not used in SQLite")] = None
 
-    echo: bool = Field(False, description="Enable SQL statement logging")
+    echo: Annotated[bool, Field(False, description="Enable SQL statement logging")] = (
+        False
+    )
 
     def _make_sqlite_url(self, connection: Connection = Connection.ASYNC) -> str:
         """SQLite URL format with async/sync support."""
@@ -355,14 +373,18 @@ class SQLServerConnectionConfig(
     BaseConnectionConfig[Literal[Driver.MSSQL], str, str, str, int, str]
 ):
     driver: Literal[Driver.MSSQL] = Driver.MSSQL
-    port: int = Field(1433, description="SQL Server port")
+    port: Annotated[int, Field(1433, description="SQL Server port")] = 1433
 
     # SQL Server-specific options
-    echo: bool = Field(False, description="Enable SQL statement logging")
-    odbc_driver: str = Field(
-        "ODBC Driver 17 for SQL Server", description="ODBC driver name"
+    echo: Annotated[bool, Field(False, description="Enable SQL statement logging")] = (
+        False
     )
-    trusted_connection: bool = Field(False, description="Use Windows Authentication")
+    odbc_driver: Annotated[
+        str, Field("ODBC Driver 17 for SQL Server", description="ODBC driver name")
+    ] = "ODBC Driver 17 for SQL Server"
+    trusted_connection: Annotated[
+        bool, Field(False, description="Use Windows Authentication")
+    ] = False
 
     @model_validator(mode="after")
     def validate_auth_method(self):
@@ -414,16 +436,25 @@ class MongoConnectionConfig(
     ]
 ):
     driver: Literal[Driver.MONGODB] = Driver.MONGODB
-    port: int = Field(27017, description="Mongo port")
-    username: OptionalString = Field(None, description="Mongo username")
-    password: OptionalString = Field(None, description="Mongo password")
+    port: Annotated[int, Field(27017, description="Mongo port")] = 27017
+    username: Annotated[OptionalString, Field(None, description="Mongo username")] = (
+        None
+    )
+    password: Annotated[OptionalString, Field(None, description="Mongo password")] = (
+        None
+    )
 
     # Mongo-specific options
-    auth_source: OptionalString = Field("admin", description="Authentication database")
-    replica_set: OptionalString = Field(None, description="Replica set name")
-    read_preference: Optional[MongoReadPreference] = Field(
-        MongoReadPreference.PRIMARY, description="Read preference"
-    )
+    auth_source: Annotated[
+        OptionalString, Field("admin", description="Authentication database")
+    ] = "admin"
+    replica_set: Annotated[
+        OptionalString, Field(None, description="Replica set name")
+    ] = None
+    read_preference: Annotated[
+        Optional[MongoReadPreference],
+        Field(MongoReadPreference.PRIMARY, description="Read preference"),
+    ] = MongoReadPreference.PRIMARY
 
     @model_validator(mode="after")
     def validate_auth_consistency(self):
@@ -463,16 +494,24 @@ class RedisConnectionConfig(
     ]
 ):
     driver: Literal[Driver.REDIS] = Driver.REDIS
-    port: int = Field(6379, description="Redis port")
-    database: int = Field(0, ge=0, le=15, description="Redis database number (0-15)")
-    username: OptionalString = Field(None, description="Redis username (Redis 6+)")
-    password: OptionalString = Field(None, description="Redis password")
+    port: Annotated[int, Field(6379, description="Redis port")] = 6379
+    database: Annotated[
+        int, Field(0, description="Redis database number (0-15)", ge=0, le=15)
+    ] = 0
+    username: Annotated[
+        OptionalString, Field(None, description="Redis username (Redis 6+)")
+    ] = None
+    password: Annotated[OptionalString, Field(None, description="Redis password")] = (
+        None
+    )
 
     # Redis-specific options
-    decode_responses: bool = Field(True, description="Decode responses to strings")
-    max_connections: Optional[int] = Field(
-        None, ge=1, description="Max connections in pool"
-    )
+    decode_responses: Annotated[
+        bool, Field(True, description="Decode responses to strings")
+    ] = True
+    max_connections: Annotated[
+        Optional[int], Field(None, ge=1, description="Max connections in pool")
+    ] = None
 
     def _make_redis_url(self) -> str:
         """Redis URL format with async/sync support."""
@@ -501,15 +540,22 @@ class ElasticsearchConnectionConfig(
     ]
 ):
     driver: Literal[Driver.ELASTICSEARCH] = Driver.ELASTICSEARCH
-    port: int = Field(9200, description="Elasticsearch port")
-    username: OptionalString = Field(None, description="Elasticsearch username")
-    password: OptionalString = Field(None, description="Elasticsearch password")
-    database: str = Field("_all", description="Elasticsearch index pattern")
+    port: Annotated[int, Field(9200, description="Elasticsearch port")] = 9200
+    username: Annotated[
+        OptionalString, Field(None, description="Elasticsearch username")
+    ] = None
+    password: Annotated[
+        OptionalString, Field(None, description="Elasticsearch password")
+    ] = None
+    database: Annotated[
+        str, Field("_all", description="Elasticsearch index pattern")
+    ] = "_all"
 
     # Elasticsearch-specific options
-    scheme: ElasticsearchScheme = Field(
-        ElasticsearchScheme.HTTP, description="Connection scheme (http/https)"
-    )
+    scheme: Annotated[
+        ElasticsearchScheme,
+        Field(ElasticsearchScheme.HTTP, description="Connection scheme (http/https)"),
+    ] = ElasticsearchScheme.HTTP
 
     @model_validator(mode="after")
     def validate_https_consistency(self):
