@@ -7,29 +7,32 @@ from pymongo import MongoClient
 from redis.asyncio import Redis as AsyncRedis
 from redis import Redis as SyncRedis
 from sqlalchemy import text
-from typing import Generic, Optional, Type, TypeVar
+from typing import Generic, Type, TypeVar, Union
 from uuid import uuid4
-from maleo.dtos.authentication import GenericAuthentication
-from maleo.dtos.contexts.operation import generate_operation_context
-from maleo.dtos.contexts.request import RequestContext
-from maleo.dtos.contexts.service import ServiceContext
-from maleo.enums.operation import (
+from maleo.logging.enums import Level
+from maleo.logging.logger import EnvironmentT, ServiceKeyT, Database
+from maleo.schemas.application import ApplicationContext, OptionalApplicationContext
+from maleo.schemas.connection import OptionalConnectionContext
+from maleo.schemas.error.enums import Code as ErrorCode
+from maleo.schemas.exception.factory import Factory as MaleoExceptionFactory
+from maleo.schemas.operation.context import generate
+from maleo.schemas.operation.enums import (
     OperationType,
     SystemOperationType,
     Origin,
     Layer,
     Target,
 )
-from maleo.exceptions import MaleoException, InternalServerError
-from maleo.logging.enums import Level
-from maleo.logging.logger import Database
-from maleo.mixins.timestamp import OperationTimestamp
+from maleo.schemas.operation.mixins import Timestamp
 from maleo.schemas.operation.system import (
     SystemOperationAction,
     SuccessfulSystemOperation,
 )
 from maleo.schemas.response import NoDataResponse
-from maleo.types.base.uuid import OptionalUUID
+from maleo.schemas.security.authentication import OptionalAnyAuthentication
+from maleo.schemas.security.authorization import OptionalAuthorization
+from maleo.schemas.security.impersonation import OptionalImpersonation
+from maleo.types.uuid import OptionalUUID
 from ..config import (
     MySQLConfig,
     PostgreSQLConfig,
@@ -57,18 +60,18 @@ class Manager(ABC, Generic[ConfigT]):
     def __init__(
         self,
         config: ConfigT,
-        logger: Database,
-        service_context: Optional[ServiceContext] = None,
+        logger: Database[EnvironmentT, ServiceKeyT],
+        application_context: OptionalApplicationContext = None,
     ) -> None:
         super().__init__()
         self._config = config
         self._logger = logger
-        self._service_context = (
-            service_context
-            if service_context is not None
-            else ServiceContext.from_env()
+        self._application_context = (
+            application_context
+            if application_context is not None
+            else ApplicationContext.from_env()
         )
-        self._operation_context = generate_operation_context(
+        self._operation_context = generate(
             origin=Origin.SERVICE,
             layer=Layer.UTILITY,
             target=Target.DATABASE,
@@ -78,8 +81,10 @@ class Manager(ABC, Generic[ConfigT]):
     async def async_check_connection(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> bool:
         pass
 
@@ -87,8 +92,10 @@ class Manager(ABC, Generic[ConfigT]):
     def sync_check_connection(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> bool:
         pass
 
@@ -103,16 +110,16 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
         Base: Type[DeclarativeBaseT],
         config: SQLConfigT,
         logger: Database,
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
     ) -> None:
-        super().__init__(config, logger, service_context)
+        super().__init__(config, logger, application_context)
         self._operation_context.target.details = self._config.model_dump()
         self._engine_manager = EngineManager[SQLConfigT](config)
         self._session_manager = SessionManager(
             config=config,
             engines=self._engine_manager.get_all(),
             logger=self._logger,
-            service_context=self._service_context,
+            application_context=self._application_context,
         )
         self.Base = Base
         self.Base.metadata.create_all(bind=self._engine_manager.get(Connection.SYNC))
@@ -128,8 +135,10 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
     async def async_check_connection(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check database connectivity by executing a simple query."""
         operation_id = operation_id if operation_id is not None else uuid4()
@@ -141,39 +150,37 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
             async with self._session_manager.get(
                 Connection.ASYNC,
                 operation_id=operation_id,
-                request_context=request_context,
+                connection_context=connection_context,
                 authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             ) as session:
                 await session.execute(text("SELECT 1"))
                 SuccessfulSystemOperation[
-                    Optional[GenericAuthentication], NoDataResponse[None]
+                    OptionalAnyAuthentication,
+                    OptionalAuthorization,
+                    NoDataResponse[None],
                 ](
-                    service_context=self._service_context,
+                    application_context=self._application_context,
                     id=operation_id,
                     context=self._operation_context,
-                    timestamp=OperationTimestamp.completed_now(executed_at),
-                    summary="Database connectivity check successful",
-                    request_context=request_context,
-                    authentication=authentication,
                     action=operation_action,
+                    timestamp=Timestamp.completed_now(executed_at),
+                    summary="Database connectivity check successful",
+                    connection_context=connection_context,
+                    authentication=authentication,
+                    authorization=authorization,
+                    impersonation=impersonation,
                     response=NoDataResponse[None](metadata=None, other=None),
                 ).log(
                     self._logger, Level.INFO
                 )
             return True
-        except MaleoException:
-            return False
         except Exception as e:
-            error = InternalServerError[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
-                operation_id=operation_id,
-                operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="Unexpected error occured checking database connection",
-                request_context=request_context,
-                authentication=authentication,
-                operation_action=operation_action,
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
                     "exc_data": {
@@ -181,16 +188,28 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
                         "args": e.args,
                     },
                 },
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="Unexpected error occured checking database connection asynchronously",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
+            exc.operation.log(self._logger, level=Level.ERROR)
             return False
 
     def sync_check_connection(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check database connectivity by executing a simple query."""
         operation_id = operation_id if operation_id is not None else uuid4()
@@ -202,39 +221,37 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
             with self._session_manager.get(
                 Connection.SYNC,
                 operation_id=operation_id,
-                request_context=request_context,
+                connection_context=connection_context,
                 authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             ) as session:
                 session.execute(text("SELECT 1"))
                 SuccessfulSystemOperation[
-                    Optional[GenericAuthentication], NoDataResponse[None]
+                    OptionalAnyAuthentication,
+                    OptionalAuthorization,
+                    NoDataResponse[None],
                 ](
-                    service_context=self._service_context,
+                    application_context=self._application_context,
                     id=operation_id,
                     context=self._operation_context,
-                    timestamp=OperationTimestamp.completed_now(executed_at),
-                    summary="Database connectivity check successful",
-                    request_context=request_context,
-                    authentication=authentication,
                     action=operation_action,
+                    timestamp=Timestamp.completed_now(executed_at),
+                    summary="Database connectivity check successful",
+                    connection_context=connection_context,
+                    authentication=authentication,
+                    authorization=authorization,
+                    impersonation=impersonation,
                     response=NoDataResponse[None](metadata=None, other=None),
                 ).log(
                     self._logger, Level.INFO
                 )
             return True
-        except MaleoException:
-            return False
         except Exception as e:
-            error = InternalServerError[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
-                operation_id=operation_id,
-                operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="Unexpected error occured checking database connection",
-                request_context=request_context,
-                authentication=authentication,
-                operation_action=operation_action,
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
                     "exc_data": {
@@ -242,9 +259,19 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
                         "args": e.args,
                     },
                 },
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="Unexpected error occured checking database connection synchronously",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
+            exc.operation.log(self._logger, level=Level.ERROR)
             return False
 
     async def dispose(self):
@@ -276,13 +303,15 @@ class SQLServerManager(
     pass
 
 
-SQLManagerT = TypeVar(
-    "SQLManagerT",
+AnySQLManager = Union[
     MySQLManager,
     PostgreSQLManager,
     SQLiteManager,
     SQLServerManager,
-)
+]
+
+
+SQLManagerT = TypeVar("SQLManagerT", bound=AnySQLManager)
 
 
 class NoSQLManager(
@@ -297,9 +326,9 @@ class NoSQLManager(
         self,
         config: NoSQLConfigT,
         logger: Database,
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
     ) -> None:
-        super().__init__(config, logger, service_context)
+        super().__init__(config, logger, application_context)
         self._operation_context.target.details = self._config.model_dump()
         self._client_manager = ClientManager[
             NoSQLConfigT,
@@ -318,8 +347,10 @@ class NoSQLManager(
     async def async_check_connection(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check client connectivity by executing a simple query."""
         client = self._client_manager.get(Connection.ASYNC)
@@ -342,8 +373,10 @@ class NoSQLManager(
     def sync_check_connection(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check client connectivity by executing a simple query."""
         client = self._client_manager.get(Connection.SYNC)
@@ -381,21 +414,17 @@ class RedisManager(NoSQLManager[RedisConfig, AsyncRedis, SyncRedis]):
     pass
 
 
-NoSQLManagerT = TypeVar(
-    "NoSQLManagerT",
+AnyNoSQLManager = Union[
     ElasticsearchManager,
     MongoManager,
     RedisManager,
-)
+]
 
 
-ManagerT = TypeVar(
-    "ManagerT",
-    ElasticsearchManager,
-    MongoManager,
-    RedisManager,
-    MySQLManager,
-    PostgreSQLManager,
-    SQLiteManager,
-    SQLServerManager,
-)
+NoSQLManagerT = TypeVar("NoSQLManagerT", bound=AnyNoSQLManager)
+
+
+AnyManager = Union[AnySQLManager, AnyNoSQLManager]
+
+
+ManagerT = TypeVar("ManagerT", bound=AnyManager)
