@@ -15,38 +15,34 @@ from typing import (
     Generator,
     Generic,
     Literal,
-    Optional,
     Tuple,
     Union,
     overload,
 )
 from uuid import uuid4
-from maleo.dtos.authentication import GenericAuthentication
-from maleo.dtos.contexts.operation import generate_operation_context
-from maleo.dtos.contexts.request import RequestContext
-from maleo.dtos.contexts.service import ServiceContext
-from maleo.enums.operation import (
+from maleo.schemas.application import ApplicationContext, OptionalApplicationContext
+from maleo.schemas.connection import OptionalConnectionContext
+from maleo.schemas.error.enums import Code as ErrorCode
+from maleo.schemas.exception.exc import MaleoException
+from maleo.schemas.exception.factory import Factory as MaleoExceptionFactory
+from maleo.schemas.operation.action.system import SystemOperationAction
+from maleo.schemas.operation.context import generate
+from maleo.schemas.operation.enums import (
     OperationType,
     SystemOperationType,
     Origin,
     Layer,
     Target,
 )
-from maleo.exceptions import (
-    MaleoException,
-    UnprocessableEntity,
-    DatabaseError,
-    InternalServerError,
-)
-from maleo.mixins.timestamp import OperationTimestamp
-from maleo.schemas.operation.system import (
-    SystemOperationAction,
-    SuccessfulSystemOperation,
-)
+from maleo.schemas.operation.mixins import Timestamp
+from maleo.schemas.operation.system import SuccessfulSystemOperation
 from maleo.schemas.response import NoDataResponse
-from maleo.types.base.uuid import OptionalUUID
+from maleo.schemas.security.authentication import OptionalAnyAuthentication
+from maleo.schemas.security.authorization import OptionalAuthorization
+from maleo.schemas.security.impersonation import OptionalImpersonation
+from maleo.types.uuid import OptionalUUID
 from maleo.logging.enums import Level
-from maleo.logging.logger import Database
+from maleo.logging.logger import EnvironmentT, ServiceKeyT, Database
 from ..enums import Connection
 from ..config import SQLConfigT
 
@@ -56,18 +52,18 @@ class SessionManager(Generic[SQLConfigT]):
         self,
         config: SQLConfigT,
         engines: Tuple[AsyncEngine, Engine],
-        logger: Database,
-        service_context: Optional[ServiceContext] = None,
+        logger: Database[EnvironmentT, ServiceKeyT],
+        application_context: OptionalApplicationContext = None,
     ):
         self._config = config
         self._async_engine, self._sync_engine = engines
         self._logger = logger
-        self._service_context = (
-            service_context
-            if service_context is not None
-            else ServiceContext.from_env()
+        self._application_context = (
+            application_context
+            if application_context is not None
+            else ApplicationContext.from_env()
         )
-        self._operation_context = generate_operation_context(
+        self._operation_context = generate(
             origin=Origin.SERVICE,
             layer=Layer.UTILITY,
             target=Target.DATABASE,
@@ -84,67 +80,65 @@ class SessionManager(Generic[SQLConfigT]):
     async def _async_session_handler(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Reusable function for managing async database session."""
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = SystemOperationAction(
             type=SystemOperationType.DATABASE_CONNECTION, details=None
         )
+
         session: AsyncSession = self._async_sessionmaker()
         SuccessfulSystemOperation[
-            Optional[GenericAuthentication], NoDataResponse[None]
+            OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
         ](
-            service_context=self._service_context,
+            application_context=self._application_context,
             id=operation_id,
             context=self._operation_context,
-            timestamp=OperationTimestamp.now(),
-            summary="Successfully created new async database session",
-            request_context=request_context,
-            authentication=authentication,
             action=operation_action,
+            timestamp=Timestamp.now(),
+            summary="Successfully created new async database session",
+            connection_context=connection_context,
+            authentication=authentication,
+            authorization=authorization,
+            impersonation=impersonation,
             response=NoDataResponse[None](metadata=None, other=None),
         ).log(
             self._logger, level=Level.DEBUG
         )
 
         executed_at = datetime.now(tz=timezone.utc)
+
         try:
             # explicit transaction context — will commit on success, rollback on exception
             async with session.begin():
                 yield session
             SuccessfulSystemOperation[
-                Optional[GenericAuthentication], NoDataResponse[None]
+                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
             ](
-                service_context=self._service_context,
+                application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
-                timestamp=OperationTimestamp.completed_now(executed_at),
-                summary="Successfully committed async database transaction",
-                request_context=request_context,
-                authentication=authentication,
                 action=operation_action,
+                timestamp=Timestamp.completed_now(executed_at),
+                summary="Successfully committed async database transaction",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
             ).log(
                 self._logger, level=Level.INFO
             )
         except SQLAlchemyError as se:
-            # session.begin() will rollback, but keep explicit rollback to be safe
-            try:
-                await session.rollback()
-            except Exception:
-                pass
-            error = DatabaseError[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
-                operation_id=operation_id,
-                operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="SQLAlchemy error occured while handling async database session",
-                request_context=request_context,
-                authentication=authentication,
-                operation_action=operation_action,
+            await session.rollback()
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(se).__name__,
                     "exc_data": {
@@ -152,51 +146,50 @@ class SessionManager(Generic[SQLConfigT]):
                         "args": se.args,
                     },
                 },
-            )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
-            raise error from se
-        except ValidationError as ve:
-            try:
-                await session.rollback()
-            except Exception:
-                pass
-            error = UnprocessableEntity[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="Validation error occured while handling async database session",
-                request_context=request_context,
-                authentication=authentication,
                 operation_action=operation_action,
-                details=ve.errors(),
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="SQLAlchemy error occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
-            raise error from ve
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from se
+        except ValidationError as ve:
+            await session.rollback()
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.UNPROCESSABLE_ENTITY,
+                details=ve.errors(),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="Validation error occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from ve
         except MaleoException:
-            try:
-                await session.rollback()
-            except Exception:
-                pass
+            await session.rollback()
             raise
         except Exception as e:
-            try:
-                await session.rollback()
-            except Exception:
-                pass
-            error = InternalServerError[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
-                operation_id=operation_id,
-                operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="Unexpected error occured while handling async database session",
-                request_context=request_context,
-                authentication=authentication,
-                operation_action=operation_action,
+            await session.rollback()
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
                     "exc_data": {
@@ -204,27 +197,35 @@ class SessionManager(Generic[SQLConfigT]):
                         "args": e.args,
                     },
                 },
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="Unexpected error occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
-            raise error from e
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from e
         finally:
-            # close session
-            try:
-                await session.close()
-            except Exception:
-                pass
+            await session.close()
             SuccessfulSystemOperation[
-                Optional[GenericAuthentication], NoDataResponse[None]
+                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
             ](
-                service_context=self._service_context,
+                application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
-                timestamp=OperationTimestamp.now(),
-                summary="Successfully closed async database session",
-                request_context=request_context,
-                authentication=authentication,
                 action=operation_action,
+                timestamp=Timestamp.now(),
+                summary="Successfully closed async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
             ).log(
                 self._logger, level=Level.INFO
@@ -233,63 +234,65 @@ class SessionManager(Generic[SQLConfigT]):
     def _sync_session_handler(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Reusable function for managing sync database session."""
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = SystemOperationAction(
             type=SystemOperationType.DATABASE_CONNECTION, details=None
         )
+
         session: Session = self._sync_sessionmaker()
         SuccessfulSystemOperation[
-            Optional[GenericAuthentication], NoDataResponse[None]
+            OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
         ](
-            service_context=self._service_context,
+            application_context=self._application_context,
             id=operation_id,
             context=self._operation_context,
-            timestamp=OperationTimestamp.now(),
-            summary="Successfully created new sync database session",
-            request_context=request_context,
-            authentication=authentication,
             action=operation_action,
+            timestamp=Timestamp.now(),
+            summary="Successfully created new sync database session",
+            connection_context=connection_context,
+            authentication=authentication,
+            authorization=authorization,
+            impersonation=impersonation,
             response=NoDataResponse[None](metadata=None, other=None),
         ).log(
             self._logger, level=Level.DEBUG
         )
 
         executed_at = datetime.now(tz=timezone.utc)
+
         try:
             # explicit transaction context — will commit on success, rollback on exception
             with session.begin():
                 yield session
             SuccessfulSystemOperation[
-                Optional[GenericAuthentication], NoDataResponse[None]
+                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
             ](
-                service_context=self._service_context,
+                application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
-                timestamp=OperationTimestamp.completed_now(executed_at),
-                summary="Successfully committed sync database transaction",
-                request_context=request_context,
-                authentication=authentication,
                 action=operation_action,
+                timestamp=Timestamp.completed_now(executed_at),
+                summary="Successfully committed sync database transaction",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
             ).log(
                 self._logger, level=Level.INFO
             )
         except SQLAlchemyError as se:
             session.rollback()  # Rollback on error
-            error = DatabaseError[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
-                operation_id=operation_id,
-                operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="SQLAlchemy error occured while handling sync database session",
-                request_context=request_context,
-                authentication=authentication,
-                operation_action=operation_action,
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(se).__name__,
                     "exc_data": {
@@ -297,41 +300,50 @@ class SessionManager(Generic[SQLConfigT]):
                         "args": se.args,
                     },
                 },
-            )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
-            raise error from se
-        except ValidationError as ve:
-            session.rollback()  # Rollback on error
-            error = UnprocessableEntity[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="Validation error occured while handling sync database session",
-                request_context=request_context,
-                authentication=authentication,
                 operation_action=operation_action,
-                details=ve.errors(),
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="SQLAlchemy error occured while handling sync database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
-            raise error from ve
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from se
+        except ValidationError as ve:
+            session.rollback()  # Rollback on error
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.UNPROCESSABLE_ENTITY,
+                details=ve.errors(),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="Validation error occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from ve
         except MaleoException:
+            session.rollback()  # Rollback on error
             raise
         except Exception as e:
             session.rollback()  # Rollback on error
-            error = InternalServerError[Optional[GenericAuthentication]](
-                OperationType.SYSTEM,
-                service_context=self._service_context,
-                operation_id=operation_id,
-                operation_context=self._operation_context,
-                operation_timestamp=OperationTimestamp.completed_now(executed_at),
-                operation_summary="Unexpected error occured while handling sync database session",
-                request_context=request_context,
-                authentication=authentication,
-                operation_action=operation_action,
+            exc = MaleoExceptionFactory[
+                OptionalAnyAuthentication, OptionalAuthorization
+            ].from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
                     "exc_data": {
@@ -339,23 +351,35 @@ class SessionManager(Generic[SQLConfigT]):
                         "args": e.args,
                     },
                 },
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="Unexpected error occured while handling sync database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
             )
-            operation = error.generate_operation(OperationType.SYSTEM)
-            operation.log(self._logger, level=Level.ERROR)
-            raise error from e
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from e
         finally:
             session.close()  # Ensure session closes
             SuccessfulSystemOperation[
-                Optional[GenericAuthentication], NoDataResponse[None]
+                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
             ](
-                service_context=self._service_context,
+                application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
-                timestamp=OperationTimestamp.now(),
-                summary="Successfully closed sync database session",
-                request_context=request_context,
-                authentication=authentication,
                 action=operation_action,
+                timestamp=Timestamp.now(),
+                summary="Successfully closed sync database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
             ).log(
                 self._logger, level=Level.INFO
@@ -365,14 +389,18 @@ class SessionManager(Generic[SQLConfigT]):
     async def _async_context_manager(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Async context manager implementation."""
         async for session in self._async_session_handler(
             operation_id,
-            request_context,
+            connection_context,
             authentication,
+            authorization,
+            impersonation,
         ):
             yield session
 
@@ -380,14 +408,18 @@ class SessionManager(Generic[SQLConfigT]):
     def _sync_context_manager(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Sync context manager implementation."""
         yield from self._sync_session_handler(
             operation_id,
-            request_context,
+            connection_context,
             authentication,
+            authorization,
+            impersonation,
         )
 
     # Overloaded context manager methods
@@ -396,8 +428,10 @@ class SessionManager(Generic[SQLConfigT]):
         self,
         connection: Literal[Connection.ASYNC],
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> AbstractAsyncContextManager[AsyncSession]: ...
 
     @overload
@@ -405,16 +439,20 @@ class SessionManager(Generic[SQLConfigT]):
         self,
         connection: Literal[Connection.SYNC],
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> AbstractContextManager[Session]: ...
 
     def get(
         self,
         connection: Connection = Connection.ASYNC,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> Union[
         AbstractAsyncContextManager[AsyncSession], AbstractContextManager[Session]
     ]:
@@ -424,14 +462,18 @@ class SessionManager(Generic[SQLConfigT]):
         if connection is Connection.ASYNC:
             return self._async_context_manager(
                 operation_id,
-                request_context,
+                connection_context,
                 authentication,
+                authorization,
+                impersonation,
             )
         else:
             return self._sync_context_manager(
                 operation_id,
-                request_context,
+                connection_context,
                 authentication,
+                authorization,
+                impersonation,
             )
 
     # Alternative: More explicit methods
@@ -439,13 +481,15 @@ class SessionManager(Generic[SQLConfigT]):
     async def get_async(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Explicit async context manager."""
         async for session in self._async_session_handler(
             operation_id,
-            request_context,
+            connection_context,
             authentication,
         ):
             yield session
@@ -454,29 +498,35 @@ class SessionManager(Generic[SQLConfigT]):
     def get_sync(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Explicit sync context manager."""
         yield from self._sync_session_handler(
             operation_id,
-            request_context,
+            connection_context,
             authentication,
         )
 
     def as_async_dependency(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ):
         """Explicit async dependency injection."""
 
         def dependency() -> AsyncGenerator[AsyncSession, None]:
             return self._async_session_handler(
                 operation_id,
-                request_context,
+                connection_context,
                 authentication,
+                authorization,
+                impersonation,
             )
 
         return dependency
@@ -484,16 +534,20 @@ class SessionManager(Generic[SQLConfigT]):
     def as_sync_dependency(
         self,
         operation_id: OptionalUUID = None,
-        request_context: Optional[RequestContext] = None,
-        authentication: Optional[GenericAuthentication] = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAuthorization = None,
+        impersonation: OptionalImpersonation = None,
     ):
         """Explicit sync dependency injection."""
 
         def dependency() -> Generator[Session, None, None]:
             return self._sync_session_handler(
                 operation_id,
-                request_context,
+                connection_context,
                 authentication,
+                authorization,
+                impersonation,
             )
 
         return dependency
