@@ -3,14 +3,14 @@ from sqlalchemy.orm import Session, aliased
 from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.sql import Select
 from sqlalchemy.types import DATE, String, TEXT, TIMESTAMP
-from typing import Sequence, Type
-from maleo.enums.sort import Order
-from maleo.mixins.general import DateFilter, SortColumn
-from maleo.types.base.any import OptionalAny
-from maleo.types.base.boolean import OptionalBoolean
-from maleo.types.base.integer import OptionalListOfIntegers
-from maleo.types.base.string import OptionalListOfStrings, OptionalString
-from maleo.types.enums.status import OptionalListOfDataStatuses
+from typing import Any, Sequence, Type
+from maleo.enums.order import Order
+from maleo.enums.status import OptionalListOfDataStatuses
+from maleo.mixins.filter import DateFilter
+from maleo.mixins.sort import SortColumn
+from maleo.types.boolean import OptionalBoolean
+from maleo.types.integer import OptionalListOfIntegers
+from maleo.types.string import OptionalListOfStrings, OptionalString
 from ..types import DeclarativeBaseT, RowT
 
 
@@ -18,7 +18,7 @@ def filter_column(
     stmt: Select[RowT],
     table: Type[DeclarativeBaseT],
     column: str,
-    value: OptionalAny = None,
+    value: Any = None,
     include_null: bool = False,
 ) -> Select[RowT]:
     column_attr = getattr(table, column, None)
